materialism
===========

This is the home page for materialism. This page contains a basic introduction for this and lots of boilerplate content.

Lorem ipsum dolor sit amet consectetur adipisicing elit. Eum sapiente tenetur nihil reiciendis perspiciatis quas ipsa ipsam, provident fugiat quaerat laboriosam numquam hic inventore dignissimos? Inventore earum culpa deleniti voluptatibus.

Lorem ipsum dolor sit amet consectetur adipisicing elit. Eum sapiente tenetur nihil reiciendis perspiciatis quas ipsa ipsam, provident fugiat quaerat laboriosam numquam hic inventore dignissimos? Inventore earum culpa deleniti voluptatibus.

Ipsum dolor
-----------

Lorem ipsum dolor sit amet consectetur adipisicing elit. Eum sapiente tenetur nihil reiciendis perspiciatis quas ipsa ipsam, provident fugiat quaerat laboriosam numquam hic inventore dignissimos? Inventore earum culpa deleniti voluptatibus.

.. toctree::
   :maxdepth: 2

   getting-started
   customisation
   demo/index
